unit Main;

interface

uses Classes, Controls, Forms, StdCtrls;

type
  TMainForm = class(TForm)
    Label1: TLabel;
    UserNameEd: TEdit;
    PasswordEd: TEdit;
    ConnectBtn: TButton;
    EventsLB: TListBox;
    EventAddBtn: TButton;
    EventEditBtn: TButton;
    EventDeleteBtn: TButton;
    EventRefreshBtn: TButton;
    Label4: TLabel;
    ServerEd: TEdit;
    GroupBox2: TGroupBox;
    procedure FormCreate(Sender: TObject);
    procedure FormDestroy(Sender: TObject);
    procedure ConnectBtnClick(Sender: TObject);
    procedure EventsLBClick(Sender: TObject);
    procedure EventAddBtnClick(Sender: TObject);
    procedure EventEditBtnClick(Sender: TObject);
    procedure EventDeleteBtnClick(Sender: TObject);
  private
    procedure UpdateEvents;
    procedure UpdateEventButtons;
  end;

var
  MainForm: TMainForm;

implementation

uses SysUtils, EditEvent, CalDAV;

{$R *.dfm}

var
  CDCalendar: TCDCalendar;

procedure TMainForm.FormCreate(Sender: TObject);
begin
  CDCalendar := TCDCalendar.Create;
//  CDCalendar.LogFileName := 'CalDAV.log';
end;

procedure TMainForm.FormDestroy(Sender: TObject);
begin
  CDCalendar.Free;
end;

procedure TMainForm.UpdateEvents;
var
  I: Integer;
begin
  EventsLB.Clear;
  Screen.Cursor := crHourGlass;
  try
    for I := 0 to CDCalendar.EventCount - 1 do
      with CDCalendar.Events[I] do
        EventsLB.Items.Add(Format('%s - %s  %s', [DateTimeToStr(StartTime), DateTimeToStr(EndTime), Title]));
  finally
    Screen.Cursor := crDefault;
  end;
  UpdateEventButtons;
end;

procedure TMainForm.UpdateEventButtons;
begin
  EventEditBtn.Enabled := EventsLB.ItemIndex >= 0;
  EventDeleteBtn.Enabled := EventsLB.ItemIndex >= 0;
end;

procedure TMainForm.ConnectBtnClick(Sender: TObject);
begin
  CDCalendar.BaseURL := ServerEd.Text;
  CDCalendar.UserName := UserNameEd.Text;
  CDCalendar.Password := PasswordEd.Text;
  CDCalendar.Load;
  EventAddBtn.Enabled := True;
  UpdateEvents;
end;

procedure TMainForm.EventsLBClick(Sender: TObject);
begin
  UpdateEventButtons;
end;

procedure TMainForm.EventAddBtnClick(Sender: TObject);
begin
  EditEventForm.Event := CDCalendar.NewEvent;
  if EditEventForm.ShowModal = mrOK then
  begin
    EventsLB.Items.Add(Format('%s - %s  %s', [DateTimeToStr(EditEventForm.Event.StartTime),
      DateTimeToStr(EditEventForm.Event.EndTime), EditEventForm.Event.Title]));
    UpdateEventButtons;
  end
  else
    CDCalendar.DeleteEvent(CDCalendar.EventCount - 1);
end;

procedure TMainForm.EventEditBtnClick(Sender: TObject);
begin
  EditEventForm.Event := CDCalendar.Events[EventsLB.ItemIndex];
  if EditEventForm.ShowModal = mrOK then
    EventsLB.Items[EventsLB.ItemIndex] := Format('%s - %s  %s', [DateTimeToStr(EditEventForm.Event.StartTime),
      DateTimeToStr(EditEventForm.Event.EndTime), EditEventForm.Event.Title]);
end;

procedure TMainForm.EventDeleteBtnClick(Sender: TObject);
begin
  CDCalendar.DeleteEvent(EventsLB.ItemIndex);
  EventsLB.Items.Delete(EventsLB.ItemIndex);
  UpdateEventButtons;
end;

end.

